@@ -1,7 +1,6 @@
-/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*- */
 /* main.c
  *
- * Copyright 2021 Chris Talbot <chris@talbothome.com>
+ * Copyright 2021-2022 Chris Talbot
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,44 +15,38 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Author(s):
- *   Chris Talbot <chris@talbothome.com>
- *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include "config.h"
 
-#include <gtk/gtk.h>
-#include <libintl.h>
-#include <locale.h>
+#include <glib/gi18n.h>
 #include <gst/gst.h>
 
-#include "vvmplayer-utils.h"
 #include "vvmplayer-application.h"
-#include "vvmplayer-log.h"
 
 int
 main (int   argc,
       char *argv[])
 {
-  g_autoptr(VvmApplication) application = NULL;
-
-  g_assert (VVMPLAYER_IS_MAIN_THREAD ());
+  g_autoptr(VvmplayerApplication) app = NULL;
+  int ret;
 
   /* Initialize GStreamer */
   gst_init (&argc, &argv);
 
-  vvmplayer_log_init ();
-
-  g_set_prgname (PACKAGE_ID);
-  application = vvmplayer_application_new ();
-  setlocale (LC_ALL, "");
-  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  return g_application_run (G_APPLICATION (application), argc, argv);
+  // Use G_APPLICATION_DEFAULT_FLAGS for GLIB 2.74 or higher
+
+  #if GLIB_CHECK_VERSION (2, 74, 0)
+  app = vvmplayer_application_new (PACKAGE_ID, G_APPLICATION_DEFAULT_FLAGS);
+  #else
+  app = vvmplayer_application_new (PACKAGE_ID, G_APPLICATION_FLAGS_NONE);
+  #endif
+  ret = g_application_run (G_APPLICATION (app), argc, argv);
+
+  return ret;
 }
